@@ -21,6 +21,13 @@ POST_LANGS = (
     ('es', 'English'),
 )
 
+ROBOTS = (
+    ('index,follow', 'Index Follow'),
+    ('index,nofollow', 'Index NOfollow'),
+    ('noindex,follow', 'NOindex, Follow'),
+    ('noindex,nofollow', 'NOindex, NOfollow'),
+)
+
 class Post(models.Model):
 
     """
@@ -45,6 +52,8 @@ class Post(models.Model):
                             blank=True, null=True, choices=POST_LANGS)
     canonical = models.CharField(_(u'Canonical'), max_length=255, blank=True,
                                  null=True)
+    robots = models.CharField(_(u'Robots behavior'), max_length=50, blank=True,
+                              null=True, choices=ROBOTS)
 
     if "rgallery" in conf.INSTALLED_APPS:
         from rgallery.models import Photo, Video
